Task templates
----------------------------------------------------

The tasks supported by :class:`datasets.Dataset.prepare_for_task` and :class:`datasets.DatasetDict.prepare_for_task`.

.. automodule:: datasets.tasks
    :members:
    :exclude-members: TaskTemplate